@@ -34,14 +34,24 @@ def ip_sort_key(x):
 
 
 def _resolve_refs(refs, attrs):
-    "Helper function to resolve reference attributes." ""
+    "Helper function to resolve reference attributes."""
+    # first resolve non-refs, then recurse alphabetically on refs.  first one wins.
+    # - first resolve on current ref
+    # - then resolve refs, alphabetically, and overwrite only if not set in map.
+    ref_attrs = []
     for t, v in list(attrs.items()):
         if isinstance(v, Reference):
-            refmap = refs.get(t)
-            if refmap:
-                ref = refmap.get(v)
-                if ref:
-                    attrs.update(_resolve_refs(refs, ref.attributes))
+            ref_attrs.append((t, v))
+
+    for t, v in sorted(ref_attrs):
+        refmap = refs.get(t)
+        if refmap:
+            ref = refmap.get(v)
+            if ref:
+                child_attrs = _resolve_refs(refs, ref.attributes.copy())
+                for at, av in child_attrs.items():
+                    if at not in attrs:
+                        attrs[at] = av
     return attrs
 
 
