@@ -22,6 +22,12 @@ class ElementRole:
     ROUTER = UUID('bf433e28-122b-41df-b49a-77ac6544deac')
     CPE_RADIO = UUID('c72115d3-daf9-43ae-9475-083d62eae74f')
 
+def has_any_fields_set(message):
+    for field_desc, value in message.ListFields():
+        if value:
+            return True
+    return False
+
 
 #import logging
 #logging.basicConfig(format='%(message)s', level=logging.INFO)
@@ -883,7 +889,10 @@ class TestModelSync(unittest.TestCase):
                 self.assertIsNotNone(package)
                 self.assertEqual(package.uuid, msvc.package_uuid)
         if ssvc.attachment:
-            self.assertEqual(ssvc.attachment.pb, msvc.attachment)
+            if has_any_fields_set(ssvc.attachment.pb):
+                self.assertEqual(ssvc.attachment.pb, msvc.attachment)
+            else:
+                self.assertIsNone(msvc.attachment)
 
     def test_service_create(self):
         """A Service is created in the model."""
@@ -1166,7 +1175,6 @@ class TestModelSync(unittest.TestCase):
             await self.checkSourceService(service)
             model_services = await self.model.Service.List(company_uuid=self.company.uuid)
             msvc = model_services[0]
-            self.model._services[msvc.company_uuid][msvc.uuid].attachment = None
 
             service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
             service.attachment.mac_addresses.append('00:01:02:03:04:05')
@@ -1175,6 +1183,28 @@ class TestModelSync(unittest.TestCase):
             await self.checkSourceService(service)
         self._await(test())
 
+    def test_service_empty_attachment(self):
+        """Comparing an empty attachment is handled properly."""
+        async def test():
+            # create a service
+            accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, 'Account 1', None, None)}
+            packages = {'pkg01': Package('pkg01', 'Package 1', 25000, 5000)}
+            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
+            services = {'service01': service}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts, packages=packages, services=services)
+            await self.checkSourceService(service)
+            model_services = await self.model.Service.List(company_uuid=self.company.uuid)
+            msvc = model_services[0]
+
+            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
+            services = {'service01': service}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts, packages=packages, services=services)
+            await self.checkSourceService(service)
+            model_services = await self.model.Service.List(company_uuid=self.company.uuid)
+            # check that we did not actually do an update
+            self.assertEqual(msvc.updated_at, model_services[0].updated_at)
+        self._await(test())
+
     async def checkSourceRouter(self, sobj):
         sites = {}
         for site in await self.model.Site.List(company_uuid=self.company.uuid):
